Remove non staged ports without pending PR from f*

This commit is contained in:
Baptiste Daroussin 2014-09-01 15:53:20 +00:00
parent a6a424630d
commit 82a079fce3
Notes: svn2git 2021-03-31 03:12:20 +00:00
svn path=/head/; revision=366890
30 changed files with 3 additions and 1307 deletions

3
MOVED
View file

@ -6609,3 +6609,6 @@ emulators/linux-geepee32||2014-09-01|Not staged
emulators/linux-systemsimcell||2014-09-01|Not staged
emulators/psim-freebsd||2014-09-01|Not staged
emulators/vMac||2014-09-01|Not staged
finance/opentaxsolver||2014-09-01|Not staged
french/facturier||2014-09-01|Not staged
ftp/vsftpd-ext||2014-09-01|Not staged

View file

@ -47,7 +47,6 @@
SUBDIR += openerp-server
SUBDIR += openerp-web
SUBDIR += openhbci
SUBDIR += opentaxsolver
SUBDIR += p5-Business-CreditCard
SUBDIR += p5-Business-MaxMind-CreditCardFraudDetection
SUBDIR += p5-Business-OCV

View file

@ -1,71 +0,0 @@
# $FreeBSD$
PORTNAME= ${UPPORTNAME:tl}
PORTVERSION= 10.00
CATEGORIES= finance
MASTER_SITES= SF/${PORTNAME}/OTS_${TAXYEAR}/v${PORTVERSION}
DISTNAME= ${UPPORTNAME}${TAXYEAR}_${PORTVERSION}
MAINTAINER= ports@FreeBSD.org
COMMENT= US tax prep software
USES= tar:tgz
PLIST= ${WRKDIR}/pkg-plist
SUB_FILES= pkg-plist
SUB_LIST= TAXYEAR=${TAXYEAR}
TAXYEAR= 2012
UPPORTNAME= OpenTaxSolver
.if !defined(WITHOUT_X11)
USE_GL= yes
USE_XORG= xmu xext x11
USES+= pkgconfig
CPPFLAGS+= $$(pkg-config --cflags-only-I glu xext xmu)
LDFLAGS+= $$(pkg-config --libs-only-L glu xext xmu)
SUB_LIST+= X11=
.else
MAKE_ENV+= WITHOUT_X11=yes
SUB_LIST+= X11="@comment "
.endif
NO_STAGE= yes
post-patch:
@${REINPLACE_CMD} -e 's/%%PREFIX%%/${PREFIX:C,/,\/,g}/' \
${WRKSRC}/src/GUI/ots_gui.c
# 9.00 distfile has pre-built (linux) binaries we must whack.
pre-build:
@(cd ${BUILD_WRKSRC}/src && make -f Makefile.unix clean && \
cd GUI && make -f Makefile.linux clean)
do-build:
@(cd ${BUILD_WRKSRC}; ${SETENV} ${MAKE_ENV} \
./Build_taxsolve_packages_LINUX.sh)
BUILDPROGLISTCMD= ${FIND} bin -type f
BUILDEXAMPLELISTCMD= ${FIND} examples_and_templates -type f
BUILDEXAMPLEDIRLISTCMD= ${FIND} examples_and_templates -type d
NEWPLIST= ${WRKDIR}/plist.new
do-install:
@(cd ${WRKSRC} && \
for prog in $$(${BUILDPROGLISTCMD}); do \
${INSTALL_PROGRAM} $${prog} ${PREFIX}/bin/. ; \
done && \
${MKDIR} ${PREFIX}/share/ots && \
for example in $$(${BUILDEXAMPLELISTCMD}); do \
${MKDIR} ${PREFIX}/share/ots/$$(dirname $${example}) && \
${INSTALL_DATA} $${example} \
${PREFIX}/share/ots/$$(dirname $${example})/. ; \
done)
new-plist:
@(cd ${WRKSRC} && \
${BUILDPROGLISTCMD} | ${SORT} > ${NEWPLIST} && \
${BUILDEXAMPLELISTCMD} | ${SED} 's,^,share/ots/,' | ${SORT} \
>> ${NEWPLIST} && \
for f in $$(${BUILDEXAMPLEDIRLISTCMD} | ${SED} 's,^,share/ots/,' && \
${ECHO_CMD} share/ots); do ${ECHO_CMD} @dirrm $$f; done | \
${SORT} -r >> ${NEWPLIST})
.include <bsd.port.mk>

View file

@ -1,2 +0,0 @@
SHA256 (OpenTaxSolver2012_10.00.tgz) = 76a016541a3cf8bb73a85178c2763dd9fd86f182951390f4102475059c6a7254
SIZE (OpenTaxSolver2012_10.00.tgz) = 480920

View file

@ -1,37 +0,0 @@
$FreeBSD$
Add year designation to 8829 solver for consistency.
--- src/Makefile.unix.orig 2012-11-25 22:34:38.000000000 -0700
+++ src/Makefile.unix 2013-04-08 09:39:31.000000000 -0600
@@ -28,7 +28,7 @@
../bin/taxsolve_NY_IT201_2012 \
../bin/taxsolve_MA_1_2012 \
../bin/taxsolve_CA_540_2012 \
- ../bin/taxsolve_US_8829
+ ../bin/taxsolve_US_8829_2012
../bin/taxsolve_US_1040_2012: taxsolve_US_1040_2012.c taxsolve_routines.c
@@ -63,8 +63,8 @@
../bin/taxsolve_MA_1_2012: taxsolve_MA_1_2012.c taxsolve_routines.c
$(CC) $(CFLAGS) $(COPTIM) -o ../bin/taxsolve_MA_1_2012 taxsolve_MA_1_2012.c $(SRCS) $(LIBS)
-../bin/taxsolve_US_8829: taxsolve_US_8829.c taxsolve_routines.c
- $(CC) $(CFLAGS) $(COPTIM) -o ../bin/taxsolve_US_8829 taxsolve_US_8829.c $(SRCS) $(LIBS)
+../bin/taxsolve_US_8829_2012: taxsolve_US_8829.c taxsolve_routines.c
+ $(CC) $(CFLAGS) $(COPTIM) -o ../bin/taxsolve_US_8829_2012 taxsolve_US_8829.c $(SRCS) $(LIBS)
clean:
--- src/GUI/ots_gui.c.orig 2013-04-07 19:40:57.000000000 -0600
+++ src/GUI/ots_gui.c 2013-04-08 09:44:22.000000000 -0600
@@ -1279,7 +1279,7 @@
"taxsolve_PA_40_2012", /* 8 */
"taxsolve_VA_760_2012", /* 9 */
"Other", /* 10 */
- "taxsolve_US_8829" /* 11 */
+ "taxsolve_US_8829_2012" /* 11 */
};

View file

@ -1,28 +0,0 @@
$FreeBSD$
--- Build_taxsolve_packages_LINUX.sh.orig 2009-05-09 11:10:10.000000000 -0600
+++ Build_taxsolve_packages_LINUX.sh 2012-02-11 09:23:27.000000000 -0700
@@ -1,11 +1,15 @@
#!/bin/sh
+# die on errors
+set -e
+
TAXSOLVEDIR=${PWD}/`dirname $0`
if [ ! -d ${TAXSOLVEDIR}/bin ] ; then
mkdir ${TAXSOLVEDIR}/bin
fi
+if [ -z "$WITHOUT_X11" -a -z "${WITHOUT_X11+isset}" ] ; then
cd ${TAXSOLVEDIR}/src/GUI/
if [ ! -d otk_lib ] ; then
echo ""
@@ -23,6 +27,7 @@
else
make -f Makefile.linux
fi
+fi
cd "${TAXSOLVEDIR}/src"
make -f Makefile.unix

View file

@ -1,15 +0,0 @@
$FreeBSD$
--- src/GUI/Makefile.linux.orig Fri Mar 31 22:16:19 2006
+++ src/GUI/Makefile.linux Mon Feb 4 21:47:35 2008
@@ -2,9 +2,9 @@
CFLAGS =
COPTIM = -O
-INCLUDE = -I/usr/X11R6/include
-LDPATH = -L/usr/X11R6/lib
+INCLUDE = ${CPPFLAGS}
+LDPATH = ${LDFLAGS}
LIBS = -lGLU -lGL -lXmu -lXext -lX11 -lm
../../bin/ots_gui:

View file

@ -1,14 +0,0 @@
$FreeBSD$
--- src/GUI/otk_lib/otk_lib.c.orig Fri Mar 31 21:42:34 2006
+++ src/GUI/otk_lib/otk_lib.c Sat Apr 8 11:50:21 2006
@@ -38,6 +38,10 @@
/* Set debug switch. 1=verbose. 0=quiet. */
#define DEBUG if (0)
+#ifdef __FreeBSD__
+#include <sys/time.h>
+#endif
+
#include "otk_lib.h"
// #include "scz_compress/scz.h" /* Optionally, include self-contained decompression library. */

View file

@ -1,108 +0,0 @@
$FreeBSD$
--- src/GUI/ots_gui.c.orig 2012-01-13 07:12:50.000000000 -0700
+++ src/GUI/ots_gui.c 2012-02-07 08:14:06.000000000 -0700
@@ -731,7 +731,7 @@
npanels = nlines / lines_per_page + 1;
if (npanels < 2) npanels = 2;
panelnames = (char **)malloc( (npanels+1) * sizeof(char *));
- for (j=0; j<npanels; j++) {panelnames[j] = (char *)malloc(30); sprintf( panelnames[j], "Page %d ", j+1); }
+ for (j=0; j<npanels; j++) {int len = 30;panelnames[j] = (char *)malloc(len); snprintf(panelnames[j], len, "Page %d ", j+1); }
Panels = Otk_Tabbed_Panel_New( main_panel, npanels, panelnames, Otk_LightGray, 1, 1, 98, 98, 5 );
TabbedPanel = Panels;
@@ -791,7 +791,7 @@
switch (entry->kind)
{
case VKIND_FLOAT: // printf("Formbox: '%s'\n", messg);
- sprintf(messg, "%12.2f", entry->value );
+ snprintf(messg, sizeof(messg), "%12.2f", entry->value );
pos_x = leftmargin;
leftmargin = leftmargin + box_width + 1.5;
pos_y = (float)linenum * 9.0 + 6.5;
@@ -1142,9 +1142,9 @@
return;
}
if (PLATFORM_KIND==Posix_Platform)
- sprintf(cmd,"%s %s &", taxsolvecmd, working_file );
+ snprintf(cmd, sizeof(cmd), "%s %s &", taxsolvecmd, working_file );
else
- sprintf(cmd,"%s %s", taxsolvecmd, working_file );
+ snprintf(cmd, sizeof(cmd), "%s %s", taxsolvecmd, working_file );
printf("Invoking '%s'\n", cmd );
system(cmd); /* Invoke the TaxSolver. */
@@ -1166,7 +1166,7 @@
viewfile = fopen( outfname, "rb" );
if (viewfile == 0)
{
- sprintf(vline,"Cannot open: %s", outfname);
+ snprintf(vline, sizeof(vline), "Cannot open: %s", outfname);
Otk_Add_Selection_Item( viewwin, vline, 0, 0 );
}
else
@@ -1206,7 +1206,7 @@
void togprntcmd_in(void *x)
{
- sprintf(printer_command,"%s %s", base_printer_command, wrkingfname);
+ snprintf(printer_command, sizeof(printer_command), "%s %s", base_printer_command, wrkingfname);
Otk_Modify_Text( printerformbox, printer_command );
}
@@ -1214,7 +1214,7 @@
{ char tmpstr[MaxFname];
int k;
predict_output_filename(wrkingfname,tmpstr);
- sprintf(printer_command,"%s %s", base_printer_command, tmpstr);
+ snprintf(printer_command, sizeof(printer_command), "%s %s", base_printer_command, tmpstr);
Otk_Modify_Text( printerformbox, printer_command );
}
@@ -1242,7 +1242,7 @@
Otk_Add_BoundingBox( printpopup, Otk_Blue, 1.0, 18.0, 16.0, 63.0, 47.0 );
if (working_file==0) strcpy(wrkingfname,filename_dat); else strcpy(wrkingfname,working_file);
- sprintf(printer_command,"%s %s", base_printer_command, wrkingfname);
+ snprintf(printer_command, sizeof(printer_command), "%s %s", base_printer_command, wrkingfname);
OtkMakeTextLabel( printpopup, "Print Command:", Otk_Black, /*scale=*/ 1.5, /*weight=*/ 1, /*x=*/ 4, /*y=*/ 57 );
printerformbox = OtkMakeTextFormBox( printpopup, printer_command, 60, 28.5, 55, 68, 18, acceptprinter_command2, 0 );
@@ -1302,15 +1302,15 @@
if (k>0) k--;
while ((k>0) && (tmpstr[k]!=slashchr)) k--;
if (tmpstr[k]==slashchr) tmpstr[k+1] = '\0';
- else {sprintf(tmpstr,".%c", slashchr);}
- sprintf(directory_dat,"%sexamples_and_templates%c", tmpstr, slashchr);
+ else {snprintf(tmpstr, sizeof(tmpstr), ".%c", slashchr);}
+ snprintf(directory_dat, sizeof(directory_dat), "%%PREFIX%%/share/ots/examples_and_templates%c", slashchr);
Otk_Browse_Files( "Select TaxForm:", MaxFname, directory_dat, wildcards_dat, taxsolvestrng, open_taxfile );
return;
}
else
{
selected_other = 0;
- sprintf(tmpstr,"%s%s", invocation_path, strg);
+ snprintf(tmpstr, sizeof(tmpstr), "%s%s", invocation_path, strg);
printf("Setting Tax Program to be: '%s'\n", tmpstr);
taxsolvecmd = strdup(tmpstr);
strcpy(taxsolvestrng,tmpstr);
@@ -1321,8 +1321,8 @@
if (k>0) k--;
while ((k>0) && (tmpstr[k]!=slashchr)) k--;
if (tmpstr[k]==slashchr) tmpstr[k+1] = '\0';
- else {sprintf(tmpstr,".%c", slashchr);}
- sprintf(directory_dat,"%sexamples_and_templates%c", tmpstr, slashchr);
+ else {snprintf(tmpstr, sizeof(tmpstr), ".%c", slashchr);}
+ snprintf(directory_dat, sizeof(directory_dat), "%%PREFIX%%/share/ots/examples_and_templates%c", slashchr);
sel = strstr( strg, "_2011" );
if (sel != 0)
@@ -1399,7 +1399,7 @@
{printf("Unknown command-line parameter '%s'\n", argv[argn]); /* exit(1); */ }
argn = argn + 1;
}
- sprintf(vrsnmssg,"OTS GUI v%1.2f", version); printf("%s\n\n",vrsnmssg);
+ snprintf(vrsnmssg, sizeof(vrsnmssg), "OTS GUI v%1.2f", version); printf("%s\n\n",vrsnmssg);
invocation_path = strdup(argv[0]);
k = strlen(invocation_path)-1;
while ((k>0) && (invocation_path[k]!=slashchr)) k--;

View file

@ -1,58 +0,0 @@
%%X11%%bin/ots_gui
bin/taxsolve_CA_540_%%TAXYEAR%%
bin/taxsolve_MA_1_%%TAXYEAR%%
bin/taxsolve_NC_D400_%%TAXYEAR%%
bin/taxsolve_NJ_1040_%%TAXYEAR%%
bin/taxsolve_NY_IT201_%%TAXYEAR%%
bin/taxsolve_OH_IT1040_%%TAXYEAR%%
bin/taxsolve_PA_40_%%TAXYEAR%%
bin/taxsolve_US_1040_%%TAXYEAR%%
bin/taxsolve_US_1040_Sched_C_%%TAXYEAR%%
bin/taxsolve_US_8829_%%TAXYEAR%%
bin/taxsolve_VA_760_%%TAXYEAR%%
share/ots/examples_and_templates/CA_540/CA_540_%%TAXYEAR%%_example.txt
share/ots/examples_and_templates/CA_540/CA_540_%%TAXYEAR%%_template.txt
share/ots/examples_and_templates/CA_540/README_CA_540.txt
share/ots/examples_and_templates/MA_1/README_MA_1.txt
share/ots/examples_and_templates/MA_1/ma_1_%%TAXYEAR%%_example.txt
share/ots/examples_and_templates/MA_1/ma_1_%%TAXYEAR%%_template.txt
share/ots/examples_and_templates/NC_D400/NC_400_%%TAXYEAR%%_example.txt
share/ots/examples_and_templates/NC_D400/NC_400_%%TAXYEAR%%_template.txt
share/ots/examples_and_templates/NC_D400/README_NC_400.txt
share/ots/examples_and_templates/NJ_1040/NJ_1040_%%TAXYEAR%%_example.txt
share/ots/examples_and_templates/NJ_1040/NJ_1040_%%TAXYEAR%%_template.txt
share/ots/examples_and_templates/NJ_1040/README_NJ_1040.txt
share/ots/examples_and_templates/NY_IT201/NY_IT201_%%TAXYEAR%%_example.txt
share/ots/examples_and_templates/NY_IT201/NY_IT201_%%TAXYEAR%%_template.txt
share/ots/examples_and_templates/NY_IT201/README_NY_IT201.txt
share/ots/examples_and_templates/OH_IT1040/OH_IT1040_%%TAXYEAR%%_example.txt
share/ots/examples_and_templates/OH_IT1040/OH_IT1040_%%TAXYEAR%%_template.txt
share/ots/examples_and_templates/OH_IT1040/README_OH_IT1040.txt
share/ots/examples_and_templates/PA_40/PA_40_%%TAXYEAR%%_example.txt
share/ots/examples_and_templates/PA_40/PA_40_%%TAXYEAR%%_template.txt
share/ots/examples_and_templates/PA_40/README_PA_40.txt
share/ots/examples_and_templates/US_1040/README_US_1040.txt
share/ots/examples_and_templates/US_1040/US_1040_example.txt
share/ots/examples_and_templates/US_1040/US_1040_example1.txt
share/ots/examples_and_templates/US_1040/US_1040_template.txt
share/ots/examples_and_templates/US_1040_Sched_C/README_US_1040_Sched_C.txt
share/ots/examples_and_templates/US_1040_Sched_C/US_1040Sched_C_%%TAXYEAR%%_example.txt
share/ots/examples_and_templates/US_1040_Sched_C/US_1040Sched_C_%%TAXYEAR%%_template.txt
share/ots/examples_and_templates/US_8829/8829_example.txt
share/ots/examples_and_templates/US_8829/8829_template.txt
share/ots/examples_and_templates/VA_760/README_VA_760.txt
share/ots/examples_and_templates/VA_760/VA_760_%%TAXYEAR%%_example.txt
share/ots/examples_and_templates/VA_760/VA_760_%%TAXYEAR%%_template.txt
@dirrm share/ots/examples_and_templates/VA_760
@dirrm share/ots/examples_and_templates/US_8829
@dirrm share/ots/examples_and_templates/US_1040_Sched_C
@dirrm share/ots/examples_and_templates/US_1040
@dirrm share/ots/examples_and_templates/PA_40
@dirrm share/ots/examples_and_templates/OH_IT1040
@dirrm share/ots/examples_and_templates/NY_IT201
@dirrm share/ots/examples_and_templates/NJ_1040
@dirrm share/ots/examples_and_templates/NC_D400
@dirrm share/ots/examples_and_templates/MA_1
@dirrm share/ots/examples_and_templates/CA_540
@dirrm share/ots/examples_and_templates
@dirrm share/ots

View file

@ -1,19 +0,0 @@
OpenTaxSolver (OTS) is a free program for calculating Tax Form
entries and tax-owed or refund-due, such as US Federal or State
personal income taxes. An optional graphical front-end, OTS_GUI,
has been added. Preliminary versions for Canada and the United
Kingdom were posted in previous years and may be updated with help
from volunteers.
Motivations include:
* To make tax preparation software available for all platforms.
* To provide insight into how our taxes are calculated in clear
unambiguous equations/code.
* To avoid invasive, bloated commercial software packages.
* To avoid rewriting our own individual programs each year by
combining efforts.
* To provide a simple reliable tax-package requiring only
rudimentary knowledge to maintain.
WWW: http://opentaxsolver.sourceforge.net/

View file

@ -11,7 +11,6 @@
SUBDIR += dico
SUBDIR += eficas
SUBDIR += eric4
SUBDIR += facturier
SUBDIR += fortune-mod-zarathoustra
SUBDIR += geonext
SUBDIR += gimp-help

View file

@ -1,121 +0,0 @@
# Created by: Thierry Thomas <thierry@pompo.net>
# $FreeBSD$
PORTNAME= facturier
PORTVERSION= 2.1.2
PORTREVISION= 4
CATEGORIES= french finance
MASTER_SITES= http://ignu.ungi.org/download/ \
${MASTER_SITE_LOCAL}
MASTER_SITE_SUBDIR= thierry
MAINTAINER= ports@FreeBSD.org
COMMENT= Logiciel de facturation pour P.M.I. & P.M.E.
RUN_DEPENDS= ${LOCALBASE}/bin/htmldoc:${PORTSDIR}/textproc/htmldoc \
p5-DBD-mysql>=0:${PORTSDIR}/databases/p5-DBD-mysql \
p5-Tie-IxHash>=0:${PORTSDIR}/devel/p5-Tie-IxHash
WRKSRC= ${WRKDIR}/${PORTNAME}
NO_BUILD= yes
USES= perl5
USE_APACHE_RUN= 22+
USE_PERL5= run
USE_MYSQL= yes
SUB_FILES= pkg-deinstall
APACHE_CONF= ${LOCALBASE}/${APACHEETCDIR}/httpd.conf
DBOWN?= PROP_BD
DBPWD?= MDP_BD
DBSERV?= localhost
FACT_CNF= lib/Conf.pm
SS_REPS= cgi-bin html lib log sql
PORTDOCS= README.txt todo.txt
FACT_HTTP_CONF= facturier.conf
SUB_FILES+= pkg-message ${FACT_HTTP_CONF}
SUB_LIST= DBOWN=${DBOWN} DBPWD=${DBPWD} DBSERV=${DBSERV} \
APACHE_CONF=${APACHE_CONF}
PKGMESSAGE= ${WRKDIR}/pkg-message
TRASHFILES= lib/Conf.pm~ cgi-bin/.articlemodif.cgi.swp lib/.Conf.pm.swp \
html/UNGI/Editfacturemaj.pm.back html/temp/log_facture.gif.back
OPTIONS_DEFINE= DOCS
NO_STAGE= yes
.include <bsd.port.options.mk>
pre-everything::
@${ECHO_MSG} ""
@${ECHO_MSG} "Vous pouvez définir trois variables :"
@${ECHO_MSG} " DBOWN pour le propriétaire de la base MySQL"
@${ECHO_MSG} "et DBPWD pour son mot de passe,"
@${ECHO_MSG} "et DBSERV pour le nom d'hôte du serveur MySQL"
@${ECHO_MSG} " (localhost par défaut)."
@${ECHO_MSG} ""
post-extract:
-@${RM} -r ${WRKSRC}/CVS
@${RM} ${TRASHFILES:S|^|${WRKSRC}/|}
post-patch:
# perl PREFIX safeness
@${FIND} ${WRKSRC}/cgi-bin -type f -print0 | ${XARGS} -0 \
${REINPLACE_CMD} -e 's|/usr/bin/perl|${PERL}|'
@${REINPLACE_CMD} -e "s:%%WWWDIR%%:${WWWDIR}:;s:%%PREFIX%%:${PREFIX}:; \
s:%%DBOWN%%:${DBOWN}:;s:%%DBPWD%%:${DBPWD}:;s:%%DBSERV%%:${DBSERV}:; \
s:%%LOCALBASE%%:${LOCALBASE}:" ${WRKSRC}/lib/Conf.pm
@${FIND} ${WRKSRC} \( -name "*.bak" -o -name "*.orig" \) -delete
@${MV} ${WRKSRC}/${FACT_CNF} ${WRKSRC}/${FACT_CNF}.dist
do-install:
@${MKDIR} ${WWWDIR}
@${INSTALL_DATA} ${WRKSRC}/version.txt ${WWWDIR}
.for REP in ${SS_REPS}
@${CP} -Rp ${WRKSRC}/${REP} ${WWWDIR}
.endfor
@[ -f ${WWWDIR}/${FACT_CNF} ] || \
${CP} ${WWWDIR}/${FACT_CNF}.dist ${WWWDIR}/${FACT_CNF}
# Set perms
@${CHOWN} -R ${WWWOWN}:${WWWGRP} ${WWWDIR}
@${CHMOD} -R 644 ${WWWDIR}
@${FIND} ${WWWDIR} -type d -exec ${CHMOD} a+x {} \;
@${CHMOD} -R u+x ${WWWDIR}/cgi-bin
@${FIND} ${WWWDIR}/lib -type f -exec ${CHMOD} go-r {} \;
@${CHMOD} -R 775 ${WWWDIR}/log
# Configure Apache
# If apache13 is gone from the ports tree,
# then it's saver to use the Include directory
${MKDIR} ${ETCDIR}
${CP} ${WRKDIR}/${FACT_HTTP_CONF} ${ETCDIR}
@(if [ -f ${APACHE_CONF} ] ; then \
${ECHO_MSG} "===> Updating ${APACHE_CONF}..." ; \
${ECHO_CMD} "# Le Facturier's cgi-bin directory" >> ${APACHE_CONF} ; \
${ECHO_CMD} "Include ${ETCDIR}" >> ${APACHE_CONF} ; \
fi)
.if ${PORT_OPTIONS:MDOCS}
@${MKDIR} ${DOCSDIR}/
@${INSTALL_DATA} ${PORTDOCS:S|^|${WRKSRC}/|} ${DOCSDIR}/
@${ECHO_MSG} "===> Documentation installed in ${DOCSDIR}."
.endif
post-install:
@${ECHO_MSG}
@${CAT} ${PKGMESSAGE}
@${ECHO_MSG}
.include <bsd.port.mk>

View file

@ -1,2 +0,0 @@
SHA256 (facturier-2.1.2.tar.gz) = 9b598b237ba31ebfd7fdb38c96c0d23db9821a44d46f3918e0718784f50e5baa
SIZE (facturier-2.1.2.tar.gz) = 645369

View file

@ -1,31 +0,0 @@
# This is included in Apache's httpd.conf for Le Facturier
<Directory "%%WWWDIR%%">
Options Indexes FollowSymLinks ExecCGI
AllowOverride None
order allow,deny
allow from all
</Directory>
<IfModule mod_alias.c>
Alias /facturier/ "%%WWWDIR%%/"
ScriptAlias /fact/ "%%WWWDIR%%/cgi-bin/"
</IfModule>
#
# For security, don't serve pages from the Facturier configuration and library
# directories.
#
<Directory "%%WWWDIR%%/lib">
Order deny,allow
Deny from all
</Directory>
<Directory "%%WWWDIR%%/log">
Order deny,allow
Deny from all
</Directory>
<Directory "%%WWWDIR%%/sql">
Order deny,allow
Deny from all
</Directory>
# End of Le Facturier configuration ================

View file

@ -1,68 +0,0 @@
--- lib/Util.pm.orig Mon Sep 22 11:39:16 2003
+++ lib/Util.pm Mon Oct 13 23:27:53 2003
@@ -67,6 +67,7 @@
=cut
sub debug {
+=port-FreeBSD sans trace
my (@DATE) = ("Janvier","Février", "Mars","Avril", "Mai", "Juin", "Juillet","Août","Septembre", "Octobre","Novembre","Décembre");
my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
$year += 1900;
@@ -82,23 +83,24 @@
my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
$atime,$mtime,$ctime,$blksize,$blocks)
- = stat("$BASEAD/log/debug.txt");
+ = stat("/var/log/facturier.log");
if ( $size >= $LOGSIZE )
{
for ( my $i=$MAXLOG;$i>1;$i--)
{
- unlink "$BASEAD/log/debug$i.txt";
+ unlink "/var/log/facturier$i.log";
my $j=$i-1;
- rename ("$BASEAD/log/debug$j.txt","$BASEAD/log/debug$i.txt");
+ rename ("/var/log/facturier$j.log","/var/log/facturier$i.log");
}
- rename ( "$BASEAD/log/debug.txt", "$BASEAD/log/debug1.txt" );
+ rename ( "/var/log/facturier.log", "/var/log/facturier1.log" );
}
#############
- open (DEBUG , ">>$BASEAD/log/debug.txt") ||
+ open (DEBUG , ">>/var/log/facturier.log") ||
&alert ("Probleme d'ouverture du fichier de debug");
print DEBUG "$date:",@_,"\n";
close (DEBUG);
+=cut
return;
}

View file

@ -1,24 +0,0 @@
#!/bin/sh
#
# $FreeBSD$
#
# Try to restore httpd.conf when deinstalling Le Facturier
if [ x$2 != xDEINSTALL ]; then
exit
fi
# honor PREFIX if installed from package
if [ ! -z $PKG_PREFIX ]; then
FACT_ETC=${PKG_PREFIX%/}/etc/facturier
else
FACT_ETC=%%ETCDIR%%
fi
APACHE_CONF=%%APACHE_CONF%%
if [ -f ${APACHE_CONF} ] ; then
echo "Cleanup httpd.conf..."
sed -i '' -e '/Include.*facturier/d' \
-e '/Le Facturier/d' ${APACHE_CONF}
fi

View file

@ -1,27 +0,0 @@
************************************************************************
Le Facturier a été installé dans %%WWWDIR%%.
Si ce n'est pas déjà fait, il faut intaller un serveur MySQL sur la
machine %%DBSERV%%
(vous pouvez utiliser un port databases/mysqlxx-server sur FreeBSD).
Vous devez maintenant créer une base MySQL sur le serveur %%DBSERV%% :
cd %%WWWDIR%%/sql
mysql -u%%DBOWN%% -p%%DBPWD%% -h%%DBSERV%% < facturier.sql
où %%DBOWN%% a le droit de créer des bases MySQL.
(Pour plus de détails, ou pour une montée de version,
Cf. %%DOCSDIR%%/README.txt)
Il faut ensuite configurer le fichier Conf.pm, qui se trouve dans
%%WWWDIR%%/lib/
en particulier les variables $USERBDD, $MDPBDD et $HOSTBDD.
Redémarrez Apache pour que les modifications de httpd.conf soient prises
en compte.
L'application est accessible depuis <http://localhost/fact/login.cgi>
(ou rempacer localhost par l'adresse de votre serveur).
Le nom de connexion initial est donné dans
%%DOCSDIR%%/README.txt
et vous devez changer son mot de passe par le menu « UTILISATEURS ».
************************************************************************

View file

@ -1,10 +0,0 @@
Le Facturier sert à établir les factures, à enregistrer les paiements
correspondants à ces factures, à préparer les factures à partir des
bons de commandes et à faire les relances.
Avec sa partie gestion des dépenses, il permet de savoir au jour le jour
où l'on en est dans la comptabilité.
[Le Facturier is a french invoicing application, for small enterprises.]
WWW: http://ignu.ungi.org/

View file

@ -1,343 +0,0 @@
%%ETCDIR%%/facturier.conf
%%WWWDIR%%/cgi-bin/articlemodif.cgi
%%WWWDIR%%/cgi-bin/articles.cgi
%%WWWDIR%%/cgi-bin/cherchcontact.cgi
%%WWWDIR%%/cgi-bin/clientmodif.cgi
%%WWWDIR%%/cgi-bin/clients.cgi
%%WWWDIR%%/cgi-bin/commande.cgi
%%WWWDIR%%/cgi-bin/depenses.cgi
%%WWWDIR%%/cgi-bin/detailclient.cgi
%%WWWDIR%%/cgi-bin/editfact.cgi
%%WWWDIR%%/cgi-bin/editfactmaj.cgi
%%WWWDIR%%/cgi-bin/entrees.cgi
%%WWWDIR%%/cgi-bin/factmodif.cgi
%%WWWDIR%%/cgi-bin/facture.cgi
%%WWWDIR%%/cgi-bin/login.cgi
%%WWWDIR%%/cgi-bin/majpropal.pl
%%WWWDIR%%/cgi-bin/modifuti.cgi
%%WWWDIR%%/cgi-bin/propal.cgi
%%WWWDIR%%/cgi-bin/propalcde.cgi
%%WWWDIR%%/cgi-bin/regler.cgi
%%WWWDIR%%/cgi-bin/relance.cgi
%%WWWDIR%%/cgi-bin/rens_article.cgi
%%WWWDIR%%/cgi-bin/rens_clifact.cgi
%%WWWDIR%%/cgi-bin/statistiques.cgi
%%WWWDIR%%/cgi-bin/taches.cgi
%%WWWDIR%%/cgi-bin/testconnection.cgi
%%WWWDIR%%/cgi-bin/testhtmldoc.cgi
%%WWWDIR%%/cgi-bin/utilisateur.cgi
%%WWWDIR%%/html/UNGI/Articles.pm
%%WWWDIR%%/html/UNGI/CherchContact.pm
%%WWWDIR%%/html/UNGI/Clients.pm
%%WWWDIR%%/html/UNGI/Commande.pm
%%WWWDIR%%/html/UNGI/Depense.pm
%%WWWDIR%%/html/UNGI/DetailClients.pm
%%WWWDIR%%/html/UNGI/Editfacture.pm
%%WWWDIR%%/html/UNGI/Editfacturemaj.pm
%%WWWDIR%%/html/UNGI/Entree.pm
%%WWWDIR%%/html/UNGI/Facture.pm
%%WWWDIR%%/html/UNGI/General.pm
%%WWWDIR%%/html/UNGI/Propal.pm
%%WWWDIR%%/html/UNGI/Relance.pm
%%WWWDIR%%/html/UNGI/Statistique.pm
%%WWWDIR%%/html/UNGI/Taches.pm
%%WWWDIR%%/html/UNGI/Utilisateur.pm
%%WWWDIR%%/html/UNGI/facture.html
%%WWWDIR%%/html/UNGI/icones/.directory
%%WWWDIR%%/html/UNGI/icones/.xvpics/OK.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/abandonner.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/ajouter.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/annuler.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/client.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/commandes.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/comment.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/complement.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/consdep.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/consfact.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/continuer.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/creecli.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/creer.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/creercde.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/creercli.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/creerfact.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/creez_uti.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/creez_uti_cli.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/defaire.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/delete.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/dep.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/depenser.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/dernier.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/droite
%%WWWDIR%%/html/UNGI/icones/.xvpics/droite.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/duplibouton.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/editer.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/editralance.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/edrel.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/enoyer.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/entree.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/euro2.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/facture.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/facturer.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/fait.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/gauche.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/generer.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/lettre.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/modifier.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/nouveau.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/premier.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/propal.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/quit.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/regler.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/relance.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/relancegax.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/reload.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/retour.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/statistiques.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/supp_uti.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/tache.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/tache_2.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/utililisateur.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/utilisateur.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/valider.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/vmoduti.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/voir.gif
%%WWWDIR%%/html/UNGI/icones/.xvpics/voir_mod.gif
%%WWWDIR%%/html/UNGI/icones/OK.gif
%%WWWDIR%%/html/UNGI/icones/abandonner.gif
%%WWWDIR%%/html/UNGI/icones/ajouter.gif
%%WWWDIR%%/html/UNGI/icones/annuler.gif
%%WWWDIR%%/html/UNGI/icones/archive.gif
%%WWWDIR%%/html/UNGI/icones/archive_a.gif
%%WWWDIR%%/html/UNGI/icones/article.gif
%%WWWDIR%%/html/UNGI/icones/boutons_01.gif
%%WWWDIR%%/html/UNGI/icones/boutons_02.gif
%%WWWDIR%%/html/UNGI/icones/boutons_03.gif
%%WWWDIR%%/html/UNGI/icones/boutons_04.gif
%%WWWDIR%%/html/UNGI/icones/client.gif
%%WWWDIR%%/html/UNGI/icones/clients.gif
%%WWWDIR%%/html/UNGI/icones/clients_2.gif
%%WWWDIR%%/html/UNGI/icones/commandes.gif
%%WWWDIR%%/html/UNGI/icones/commandes_2.gif
%%WWWDIR%%/html/UNGI/icones/comment.gif
%%WWWDIR%%/html/UNGI/icones/complement.gif
%%WWWDIR%%/html/UNGI/icones/consdep.gif
%%WWWDIR%%/html/UNGI/icones/conseil/help.gif
%%WWWDIR%%/html/UNGI/icones/conseil/ungips.gif
%%WWWDIR%%/html/UNGI/icones/consfact.gif
%%WWWDIR%%/html/UNGI/icones/continuer.gif
%%WWWDIR%%/html/UNGI/icones/creeart.gif
%%WWWDIR%%/html/UNGI/icones/creecli.gif
%%WWWDIR%%/html/UNGI/icones/creer.gif
%%WWWDIR%%/html/UNGI/icones/creer_facture.gif
%%WWWDIR%%/html/UNGI/icones/creer_facture2.gif
%%WWWDIR%%/html/UNGI/icones/creer_larticle.gif
%%WWWDIR%%/html/UNGI/icones/creer_util1.gif
%%WWWDIR%%/html/UNGI/icones/creer_util2.gif
%%WWWDIR%%/html/UNGI/icones/creer_util_client1.gif
%%WWWDIR%%/html/UNGI/icones/creer_util_client2.gif
%%WWWDIR%%/html/UNGI/icones/creercde.gif
%%WWWDIR%%/html/UNGI/icones/creercli.gif
%%WWWDIR%%/html/UNGI/icones/creerfact.gif
%%WWWDIR%%/html/UNGI/icones/creez_uti.gif
%%WWWDIR%%/html/UNGI/icones/creez_uti_cli.gif
%%WWWDIR%%/html/UNGI/icones/decrementer.gif
%%WWWDIR%%/html/UNGI/icones/defaire.gif
%%WWWDIR%%/html/UNGI/icones/delete.gif
%%WWWDIR%%/html/UNGI/icones/dep.gif
%%WWWDIR%%/html/UNGI/icones/depenser.gif
%%WWWDIR%%/html/UNGI/icones/depenses.gif
%%WWWDIR%%/html/UNGI/icones/depenses_2.gif
%%WWWDIR%%/html/UNGI/icones/dernier.gif
%%WWWDIR%%/html/UNGI/icones/detruire.gif
%%WWWDIR%%/html/UNGI/icones/droite
%%WWWDIR%%/html/UNGI/icones/droite.gif
%%WWWDIR%%/html/UNGI/icones/duplibouton.gif
%%WWWDIR%%/html/UNGI/icones/duplicata.gif
%%WWWDIR%%/html/UNGI/icones/edit_relance1.gif
%%WWWDIR%%/html/UNGI/icones/edit_relance2.gif
%%WWWDIR%%/html/UNGI/icones/edit_relance_fax1.gif
%%WWWDIR%%/html/UNGI/icones/edit_relance_fax2.gif
%%WWWDIR%%/html/UNGI/icones/editer.gif
%%WWWDIR%%/html/UNGI/icones/editrelance.gif
%%WWWDIR%%/html/UNGI/icones/edrel.gif
%%WWWDIR%%/html/UNGI/icones/en/help.gif
%%WWWDIR%%/html/UNGI/icones/en/konica.gif
%%WWWDIR%%/html/UNGI/icones/en/konicahelp.gif
%%WWWDIR%%/html/UNGI/icones/en/ungips.gif
%%WWWDIR%%/html/UNGI/icones/entree.gif
%%WWWDIR%%/html/UNGI/icones/entrees.gif
%%WWWDIR%%/html/UNGI/icones/entrees_2.gif
%%WWWDIR%%/html/UNGI/icones/envoyer.gif
%%WWWDIR%%/html/UNGI/icones/euro.gif
%%WWWDIR%%/html/UNGI/icones/euro1.gif
%%WWWDIR%%/html/UNGI/icones/euro2.gif
%%WWWDIR%%/html/UNGI/icones/facture.gif
%%WWWDIR%%/html/UNGI/icones/facturer.gif
%%WWWDIR%%/html/UNGI/icones/factures.gif
%%WWWDIR%%/html/UNGI/icones/factures_2.gif
%%WWWDIR%%/html/UNGI/icones/facturier.gif
%%WWWDIR%%/html/UNGI/icones/faire.gif
%%WWWDIR%%/html/UNGI/icones/fleche.gif
%%WWWDIR%%/html/UNGI/icones/fond.gif
%%WWWDIR%%/html/UNGI/icones/fond2.gif
%%WWWDIR%%/html/UNGI/icones/fond3.gif
%%WWWDIR%%/html/UNGI/icones/fond_tetiere.gif
%%WWWDIR%%/html/UNGI/icones/fr/.xvpics/facturier.png
%%WWWDIR%%/html/UNGI/icones/fr/facturier.png
%%WWWDIR%%/html/UNGI/icones/gauche.gif
%%WWWDIR%%/html/UNGI/icones/generer.gif
%%WWWDIR%%/html/UNGI/icones/global.gif
%%WWWDIR%%/html/UNGI/icones/global_a.gif
%%WWWDIR%%/html/UNGI/icones/help.gif
%%WWWDIR%%/html/UNGI/icones/help_a.gif
%%WWWDIR%%/html/UNGI/icones/imprimer.gif
%%WWWDIR%%/html/UNGI/icones/incrementer.gif
%%WWWDIR%%/html/UNGI/icones/installer.gif
%%WWWDIR%%/html/UNGI/icones/installer.gif~
%%WWWDIR%%/html/UNGI/icones/installer_a.gif
%%WWWDIR%%/html/UNGI/icones/installer_a.gif~
%%WWWDIR%%/html/UNGI/icones/konica.gif
%%WWWDIR%%/html/UNGI/icones/lettre.gif
%%WWWDIR%%/html/UNGI/icones/liste.gif
%%WWWDIR%%/html/UNGI/icones/liste2.gif
%%WWWDIR%%/html/UNGI/icones/log_facture.gif
%%WWWDIR%%/html/UNGI/icones/log_ungi.gif
%%WWWDIR%%/html/UNGI/icones/logo_rdl.gif
%%WWWDIR%%/html/UNGI/icones/logo_ungi.gif
%%WWWDIR%%/html/UNGI/icones/lum_or.gif
%%WWWDIR%%/html/UNGI/icones/mensuel.gif
%%WWWDIR%%/html/UNGI/icones/modifier.gif
%%WWWDIR%%/html/UNGI/icones/montage.gif
%%WWWDIR%%/html/UNGI/icones/nouveau.gif
%%WWWDIR%%/html/UNGI/icones/options.gif
%%WWWDIR%%/html/UNGI/icones/orange.gif
%%WWWDIR%%/html/UNGI/icones/pixel.gif
%%WWWDIR%%/html/UNGI/icones/premier.gif
%%WWWDIR%%/html/UNGI/icones/printers.gif
%%WWWDIR%%/html/UNGI/icones/printers_a.gif
%%WWWDIR%%/html/UNGI/icones/propal.gif
%%WWWDIR%%/html/UNGI/icones/propal_2.gif
%%WWWDIR%%/html/UNGI/icones/propal_commande.gif
%%WWWDIR%%/html/UNGI/icones/quit.gif
%%WWWDIR%%/html/UNGI/icones/quit_a.gif
%%WWWDIR%%/html/UNGI/icones/quitter.gif
%%WWWDIR%%/html/UNGI/icones/quitter2.gif
%%WWWDIR%%/html/UNGI/icones/quitter2a.gif
%%WWWDIR%%/html/UNGI/icones/regler.gif
%%WWWDIR%%/html/UNGI/icones/regler2.gif
%%WWWDIR%%/html/UNGI/icones/relance.gif
%%WWWDIR%%/html/UNGI/icones/relance_2.gif
%%WWWDIR%%/html/UNGI/icones/relancefax.gif
%%WWWDIR%%/html/UNGI/icones/relancer.gif
%%WWWDIR%%/html/UNGI/icones/reload.gif
%%WWWDIR%%/html/UNGI/icones/retour.gif
%%WWWDIR%%/html/UNGI/icones/retour_liste.gif
%%WWWDIR%%/html/UNGI/icones/retour_liste2.gif
%%WWWDIR%%/html/UNGI/icones/rouge.GIF
%%WWWDIR%%/html/UNGI/icones/rouge.gif
%%WWWDIR%%/html/UNGI/icones/run.gif
%%WWWDIR%%/html/UNGI/icones/sauve.gif
%%WWWDIR%%/html/UNGI/icones/spool.gif
%%WWWDIR%%/html/UNGI/icones/spool_a.gif
%%WWWDIR%%/html/UNGI/icones/stat.gif
%%WWWDIR%%/html/UNGI/icones/stat_a.gif
%%WWWDIR%%/html/UNGI/icones/statistiques.gif
%%WWWDIR%%/html/UNGI/icones/statistiques_2.gif
%%WWWDIR%%/html/UNGI/icones/stop.gif
%%WWWDIR%%/html/UNGI/icones/supp_uti.gif
%%WWWDIR%%/html/UNGI/icones/supprimer.gif
%%WWWDIR%%/html/UNGI/icones/tache.gif
%%WWWDIR%%/html/UNGI/icones/tache_2.gif
%%WWWDIR%%/html/UNGI/icones/tetiere_01.gif
%%WWWDIR%%/html/UNGI/icones/tetiere_09.gif
%%WWWDIR%%/html/UNGI/icones/undo.gif
%%WWWDIR%%/html/UNGI/icones/ungi.gif
%%WWWDIR%%/html/UNGI/icones/ungiforum.gif
%%WWWDIR%%/html/UNGI/icones/users.gif
%%WWWDIR%%/html/UNGI/icones/users_a.gif
%%WWWDIR%%/html/UNGI/icones/utilisateur.gif
%%WWWDIR%%/html/UNGI/icones/utilisateurs.gif
%%WWWDIR%%/html/UNGI/icones/utilisateurs_2.gif
%%WWWDIR%%/html/UNGI/icones/valider.gif
%%WWWDIR%%/html/UNGI/icones/valider_login.gif
%%WWWDIR%%/html/UNGI/icones/validercreat.gif
%%WWWDIR%%/html/UNGI/icones/validermodif.gif
%%WWWDIR%%/html/UNGI/icones/vert.GIF
%%WWWDIR%%/html/UNGI/icones/vert.gif
%%WWWDIR%%/html/UNGI/icones/vmoduti.gif
%%WWWDIR%%/html/UNGI/icones/voir.gif
%%WWWDIR%%/html/UNGI/icones/voir3.gif
%%WWWDIR%%/html/UNGI/icones/voir_facture.gif
%%WWWDIR%%/html/UNGI/icones/voir_mod.gif
%%WWWDIR%%/html/UNGI/icones/voirlettre.gif
%%WWWDIR%%/html/UNGI/lang/Fr.pm
%%WWWDIR%%/html/UNGI/style.css
%%WWWDIR%%/html/index.html
%%WWWDIR%%/html/javascript.js
%%WWWDIR%%/html/temp/duplicata.gif
%%WWWDIR%%/html/temp/euro2.gif
%%WWWDIR%%/html/temp/facture.tar.gz
%%WWWDIR%%/html/temp/log_ungi.gif
%%WWWDIR%%/html/temp/page1002_1061990822
%%WWWDIR%%/html/temp/page1002_1061990966
%%WWWDIR%%/html/temp/page1009_1061990822
%%WWWDIR%%/html/temp/page1009_1061990966
%%WWWDIR%%/html/temp/page1014_1061990822
%%WWWDIR%%/html/temp/page1014_1061990966
%%WWWDIR%%/html/temp/page1027_1061990822
%%WWWDIR%%/html/temp/page1027_1061990966
%%WWWDIR%%/html/temp/page1028_1061990822
%%WWWDIR%%/html/temp/page1028_1061990966
%%WWWDIR%%/html/temp/page1031_1061990822
%%WWWDIR%%/html/temp/page1031_1061990966
%%WWWDIR%%/html/temp/page1046_1061990822
%%WWWDIR%%/html/temp/page1046_1061990966
%%WWWDIR%%/html/temp/page746_1061990822
%%WWWDIR%%/html/temp/page746_1061990966
%%WWWDIR%%/html/temp/page768_1061990822
%%WWWDIR%%/html/temp/page768_1061990966
%%WWWDIR%%/html/temp/page773_1061990822
%%WWWDIR%%/html/temp/page773_1061990966
%%WWWDIR%%/html/temp/page776_1061990822
%%WWWDIR%%/html/temp/page776_1061990966
%%WWWDIR%%/html/temp/page778_1061990822
%%WWWDIR%%/html/temp/page778_1061990966
%%WWWDIR%%/html/temp/page780_1061990822
%%WWWDIR%%/html/temp/page780_1061990966
%%WWWDIR%%/html/temp/page819_1061990822
%%WWWDIR%%/html/temp/page819_1061990966
%%WWWDIR%%/html/temp/page858_1061990822
%%WWWDIR%%/html/temp/page858_1061990966
%%WWWDIR%%/html/temp/page926_1061990822
%%WWWDIR%%/html/temp/page926_1061990966
%%WWWDIR%%/html/temp/relance.pdf
@unexec if cmp -s %D/%%WWWDIR%%/lib/Conf.pm %D/%%WWWDIR%%/lib/Conf.pm.dist; then rm -f %D/%%WWWDIR%%/lib/Conf.pm; fi
%%WWWDIR%%/lib/Conf.pm.dist
@exec [ -f %D/%%WWWDIR%%/lib/Conf.pm ] || cp %D/%%WWWDIR%%/lib/Conf.pm.dist %D/%%WWWDIR%%/lib/Conf.pm
%%WWWDIR%%/lib/Util.pm
%%WWWDIR%%/lib/lang/Fr.pm
%%WWWDIR%%/lib/lang/Fr.pm.back
%%WWWDIR%%/lib/statfact.conf
%%WWWDIR%%/lib/usertype.conf
%%WWWDIR%%/log/debug.txt
%%WWWDIR%%/log/debug1.txt
%%WWWDIR%%/sql/facturier.sql
%%WWWDIR%%/sql/majvers2.1.1tovers2.1.2.sql
%%WWWDIR%%/version.txt
@dirrm %%WWWDIR%%/sql
@dirrm %%WWWDIR%%/log
@dirrm %%WWWDIR%%/lib/lang
@dirrmtry %%WWWDIR%%/lib
@dirrm %%WWWDIR%%/html/temp
@dirrm %%WWWDIR%%/html/UNGI/lang
@dirrm %%WWWDIR%%/html/UNGI/icones/fr/.xvpics
@dirrm %%WWWDIR%%/html/UNGI/icones/fr
@dirrm %%WWWDIR%%/html/UNGI/icones/en
@dirrm %%WWWDIR%%/html/UNGI/icones/conseil
@dirrm %%WWWDIR%%/html/UNGI/icones/.xvpics
@dirrm %%WWWDIR%%/html/UNGI/icones
@dirrm %%WWWDIR%%/html/UNGI
@dirrm %%WWWDIR%%/html
@dirrm %%WWWDIR%%/cgi-bin
@dirrmtry %%WWWDIR%%
@dirrm %%ETCDIR%%

View file

@ -93,7 +93,6 @@
SUBDIR += uftp
SUBDIR += urlgfe
SUBDIR += vsftpd
SUBDIR += vsftpd-ext
SUBDIR += waiho
SUBDIR += weex
SUBDIR += wget

View file

@ -1,107 +0,0 @@
# Created by: Maxim Ignatenko
# $FreeBSD$
PORTNAME= vsftpd-ext
PORTVERSION= ${UPSTREAMVERSION}.${EXTVERSION}
PORTREVISION= 1
CATEGORIES= ftp ipv6
MASTER_SITES= http://vsftpd.devnet.ru/files/${UPSTREAMVERSION}/ext.${EXTVERSION}/
PKGNAMESUFFIX?= ${SSL_SUFFIX}${PKGNAMESUFFIX2}
DISTNAME= vsFTPd-${UPSTREAMVERSION}-ext${EXTVERSION}
EXTRACT_SUFX= .tgz
MAINTAINER= ports@FreeBSD.org
COMMENT= FTP daemon that aims to be "very secure". Extended build
CONFLICTS= vsftpd-2* vsftpd${SSL_SUFFIX}${PKGNAMESUFFIX2}-2*
UPSTREAMVERSION= 2.3.5
EXTVERSION= 1
WRKSRC= ${WRKDIR}/vsFTPd-${UPSTREAMVERSION}-ext.${EXTVERSION}
ALL_TARGET= vsftpd
MAN5= vsftpd.conf.5
MAN8= vsftpd.8
DOCFILES= AUDIT BENCHMARKS BUGS Changelog FAQ INSTALL LICENSE \
README README.security README.ssl REFS REWARD \
SIZE SPEED TODO TUNING
OPTIONS_DEFINE= RC_SCRIPT SSL DOCS
OPTIONS_DEFAULT= RC_SCRIPT
RC_SCRIPT_DESC= install RC_SCRIPT
NO_STAGE= yes
.include <bsd.port.options.mk>
.if ${PORT_OPTIONS:MRC_SCRIPT}
USE_RC_SUBR= vsftpd
.endif
.if ${PORT_OPTIONS:MSSL}
USE_OPENSSL= yes
SSL_SUFFIX= -ssl
CFLAGS+= -I${OPENSSLINC}
LDFLAGS+= -L${OPENSSLLIB}
.endif
do-configure:
${REINPLACE_CMD} -e "s|/etc/vsftpd|${PREFIX}/etc|" \
${WRKSRC}/builddefs.h
${REINPLACE_CMD} \
-e '/^CC/s/=/?=/' \
-e '/^CFLAGS/{s/=/+=/;s/-O[0-9]//;}' \
-e '/^LIBS/s|=.*|= `./vsf_findlibs.sh`|' \
-e '/^LINK/s/=.*/=/' \
${WRKSRC}/Makefile
${REINPLACE_CMD} -e '/-lutil/d' ${WRKSRC}/vsf_findlibs.sh
${REINPLACE_CMD} -e \
"s|#undef VSF_BUILD_TCPWRAPPERS|#define VSF_BUILD_TCPWRAPPERS 1|" \
${WRKSRC}/builddefs.h
@${ECHO_CMD} "secure_chroot_dir=${PREFIX}/share/vsftpd/empty" >> \
${WRKSRC}/vsftpd.conf
@${ECHO_CMD} >>${WRKSRC}/vsftpd.conf ""
@${ECHO_CMD} >>${WRKSRC}/vsftpd.conf \
"# If using vsftpd in standalone mode, uncomment the next two lines:"
@${ECHO_CMD} >>${WRKSRC}/vsftpd.conf "# listen=YES"
@${ECHO_CMD} >>${WRKSRC}/vsftpd.conf "# background=YES"
${REINPLACE_CMD} -e "s|/etc/v|${PREFIX}/etc/v|" \
-e 's|delay_failed_logins|delay_failed_login|' \
-e 's|delay_successful_logins|delay_successful_login|' \
${WRKSRC}/vsftpd.8 ${WRKSRC}/vsftpd.conf.5 ${WRKSRC}/tunables.c
.if ${PORT_OPTIONS:MSSL}
${REINPLACE_CMD} -e \
"s|#undef VSF_BUILD_SSL|#define VSF_BUILD_SSL 1|" \
${WRKSRC}/builddefs.h
.endif
pre-install:
${SETENV} PKG_PREFIX=${PREFIX} ${SH} ${PKGINSTALL} ${PKGNAME} PRE-INSTALL
do-install:
${INSTALL_PROGRAM} ${WRKSRC}/vsftpd ${PREFIX}/libexec/
${INSTALL_DATA} ${WRKSRC}/vsftpd.conf ${PREFIX}/etc/vsftpd.conf.dist
${INSTALL} -d ${PREFIX}/share/vsftpd/empty
@if [ ! -e ${PREFIX}/etc/vsftpd.conf ]; then \
${INSTALL_DATA} ${WRKSRC}/vsftpd.conf ${PREFIX}/etc/ ; \
fi
${MKDIR} ${PREFIX}/share/vsftpd/empty
@for i in ${MAN8} ; do \
${INSTALL_MAN} -m 644 ${WRKSRC}/$${i} ${MANPREFIX}/man/man8/ ; \
done
@for i in ${MAN5} ; do \
${INSTALL_MAN} -m 644 ${WRKSRC}/$${i} ${MANPREFIX}/man/man5/ ; \
done
${MKDIR} /var/ftp
.if ${PORT_OPTIONS:MDOCS}
${MKDIR} ${DOCSDIR}
.for i in ${DOCFILES}
${INSTALL_DATA} -m 644 ${WRKSRC}/${i} ${DOCSDIR}
.endfor
.for i in EXAMPLE SECURITY
${MKDIR} ${DOCSDIR}/${i}
${CP} -p -R -L ${WRKSRC}/${i}/./ ${DOCSDIR}/${i}/
${CHMOD} -R -L a+rX,go-w ${DOCSDIR}/${i}/
.endfor
.endif
.include <bsd.port.mk>

View file

@ -1,2 +0,0 @@
SHA256 (vsFTPd-2.3.5-ext1.tgz) = 2eeee4955565e6d6f9b21ab9a199689488d6d62c0024f6415dbd4510f85d43fe
SIZE (vsFTPd-2.3.5-ext1.tgz) = 222249

View file

@ -1,13 +0,0 @@
--- utility.c.orig Fri Jul 2 18:26:30 2004
+++ utility.c Mon Oct 10 01:19:02 2005
@@ -33,6 +33,10 @@
void
bug(const char* p_text)
{
+ static int inside_bug = 0;
+ if (inside_bug)
+ vsf_sysutil_exit(1);
+ inside_bug++;
/* Rats. Try and write the reason to the network for diagnostics */
vsf_sysutil_activate_noblock(VSFTP_COMMAND_FD);
(void) vsf_sysutil_write_loop(VSFTP_COMMAND_FD, "500 OOPS: ", 10);

View file

@ -1,51 +0,0 @@
#!/bin/sh
#
# $FreeBSD$
#
# PROVIDE: vsftpd
# REQUIRE: DAEMON
# To enable 'vsftpd' in standalone mode, you need to edit two files.
# 1. add the following line(s) to /etc/rc.conf to enable `vsftpd':
#
# vsftpd_enable="YES"
# vsftpd_flags="/some/path/conf.file" # Not required
#
# 2. tell vsftpd about standalone mode
# Edit %%PREFIX%%/etc/vsftpd.conf (or /some/path/conf.file) to contain
#
# listen=YES
# background=YES
#
# Samples are provided at the end of the configuration file.
. /etc/rc.subr
name="vsftpd"
rcvar=vsftpd_enable
load_rc_config "$name"
: ${vsftpd_enable:="NO"}
command="%%PREFIX%%/libexec/$name"
required_files="%%PREFIX%%/etc/$name.conf"
start_precmd="vsftpd_check"
vsftpd_check()
{
if grep -q "^ftp[ ]" /etc/inetd.conf ${required_files}
then
err 1 "ftp is already activated in /etc/inetd.conf"
fi
if ! egrep -q -i -E "^listen.*=.*YES$" ${required_files}
then
err 1 'vsftpd script need "listen=YES" in config file'
fi
if ! egrep -q -i -E "^background.*=.*YES$" ${required_files}
then
err 1 'vsftpd script need "background=YES" in config file'
fi
}
run_rc_command "$1"

View file

@ -1,16 +0,0 @@
#!/bin/sh
# $FreeBSD: /tmp/pcvs/ports/ftp/vsftpd-ext/pkg-deinstall,v 1.1 2009-06-16 03:53:39 pgollucci Exp $
#
if [ "$2" != "POST-DEINSTALL" ]; then
exit 0
fi
USER=ftp
if pw usershow "${USER}" 2>/dev/null 1>&2; then
echo "To delete FTP user permanently, use 'pw userdel ${USER}'"
echo "Don't do this if you're using FreeBSD's anonymous FTP server"
fi
exit 0

View file

@ -1,3 +0,0 @@
Extended build of vsftpd with additional features.
WWW: http://vsftpd.devnet.ru/eng/

View file

@ -1,36 +0,0 @@
#!/bin/sh
# $FreeBSD: /tmp/pcvs/ports/ftp/vsftpd-ext/pkg-install,v 1.1 2009-06-16 03:53:39 pgollucci Exp $
#
if [ "$2" != "PRE-INSTALL" ]; then
exit 0
fi
if ! pw groupshow operator >/dev/null; then
if pw groupadd operator 5; then
echo "Added group operator for vsftpd"
else
echo "Failed to add group operator as gid 5" >&2
exit 1
fi
fi
if ! pw usershow ftp >/dev/null; then
if pw useradd ftp -g operator -u 14 -h - -d /var/ftp -s /nonexistent -c "Anonymous Ftp"; then
echo "Added user ftp for vsftpd"
else
echo "Failed to add user ftp as gid 14" >&2
exit 1
fi
fi
# uid=14(ftp) gid=5(operator) groups=5(operator)
view="$(id ftp)"
view="${view%% *}"
if test "${view}" = "uid=14(ftp)"; then
exit 0
fi
echo "User ftp should have uid 14"; >&2
exit 1
# eof

View file

@ -1,58 +0,0 @@
libexec/vsftpd
@exec mkdir -p %D/share/vsftpd/empty
@unexec if diff -q %D/etc/vsftpd.conf %D/etc/vsftpd.conf.dist; then rm %D/etc/vsftpd.conf; fi
etc/vsftpd.conf.dist
@exec if [ ! -f %B/vsftpd.conf ]; then cp %B/vsftpd.conf.dist %B/vsftpd.conf; fi
@exec if [ ! -d /var/ftp ]; then mkdir /var/ftp ; fi
@unexec rmdir /var/ftp 2>/dev/null || true
@dirrm share/vsftpd/empty
@dirrm share/vsftpd
%%PORTDOCS%%%%DOCSDIR%%/AUDIT
%%PORTDOCS%%%%DOCSDIR%%/BENCHMARKS
%%PORTDOCS%%%%DOCSDIR%%/BUGS
%%PORTDOCS%%%%DOCSDIR%%/Changelog
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/HTTP_TEMPLATES/403.html
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/HTTP_TEMPLATES/browse_line.html
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/HTTP_TEMPLATES/browse.html
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/HTTP_TEMPLATES/403-serv.html
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/HTTP_TEMPLATES/404.html
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/INTERNET_SITE/README
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/INTERNET_SITE/vsftpd.conf
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/INTERNET_SITE/vsftpd.xinetd
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/INTERNET_SITE_NOINETD/README
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/INTERNET_SITE_NOINETD/vsftpd.conf
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/PER_IP_CONFIG/README
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/PER_IP_CONFIG/hosts.allow
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/README
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/VIRTUAL_HOSTS/README
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/VIRTUAL_USERS/README
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/VIRTUAL_USERS/logins.txt
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/VIRTUAL_USERS/vsftpd.conf
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/VIRTUAL_USERS/vsftpd.pam
%%PORTDOCS%%%%DOCSDIR%%/EXAMPLE/VIRTUAL_USERS_2/README
%%PORTDOCS%%%%DOCSDIR%%/FAQ
%%PORTDOCS%%%%DOCSDIR%%/INSTALL
%%PORTDOCS%%%%DOCSDIR%%/LICENSE
%%PORTDOCS%%%%DOCSDIR%%/README
%%PORTDOCS%%%%DOCSDIR%%/README.security
%%PORTDOCS%%%%DOCSDIR%%/README.ssl
%%PORTDOCS%%%%DOCSDIR%%/REFS
%%PORTDOCS%%%%DOCSDIR%%/REWARD
%%PORTDOCS%%%%DOCSDIR%%/SECURITY/DESIGN
%%PORTDOCS%%%%DOCSDIR%%/SECURITY/IMPLEMENTATION
%%PORTDOCS%%%%DOCSDIR%%/SECURITY/OVERVIEW
%%PORTDOCS%%%%DOCSDIR%%/SECURITY/TRUST
%%PORTDOCS%%%%DOCSDIR%%/SIZE
%%PORTDOCS%%%%DOCSDIR%%/SPEED
%%PORTDOCS%%%%DOCSDIR%%/TODO
%%PORTDOCS%%%%DOCSDIR%%/TUNING
%%PORTDOCS%%@dirrm %%DOCSDIR%%/EXAMPLE/HTTP_TEMPLATES
%%PORTDOCS%%@dirrm %%DOCSDIR%%/EXAMPLE/INTERNET_SITE
%%PORTDOCS%%@dirrm %%DOCSDIR%%/EXAMPLE/INTERNET_SITE_NOINETD
%%PORTDOCS%%@dirrm %%DOCSDIR%%/EXAMPLE/PER_IP_CONFIG
%%PORTDOCS%%@dirrm %%DOCSDIR%%/EXAMPLE/VIRTUAL_HOSTS
%%PORTDOCS%%@dirrm %%DOCSDIR%%/EXAMPLE/VIRTUAL_USERS
%%PORTDOCS%%@dirrm %%DOCSDIR%%/EXAMPLE/VIRTUAL_USERS_2
%%PORTDOCS%%@dirrm %%DOCSDIR%%/EXAMPLE
%%PORTDOCS%%@dirrm %%DOCSDIR%%/SECURITY
%%PORTDOCS%%@dirrm %%DOCSDIR%%
--- lib/Conf.pm.orig Thu Mar 31 10:30:48 2005
+++ lib/Conf.pm Sat Jun 18 19:09:46 2005
@@ -70,24 +70,24 @@
#$USERBDD à pour valeur le login d'un utilisateur pouvant se connecter
#à la base de donnée 'FACTURIER' sur le serveur MySQL
#remplacer 'user' par le login d'un utilisateur ayant le droit d'utiliser
#la base de donnée 'facturier' sur le serveur MySQL
-my $USERBDD="user";
+my $USERBDD="%%DBOWN%%";
#$MDPBDD contient la valeur du mot de passe de connection de l'utilisateur
#$USERBDD au serveur MySQL
#remplacer 'password' par le mot de passe du login de l'utilisateur
#ci-dessus
-my $MDPBDD="password";
+my $MDPBDD="%%DBPWD%%";
#base de donnes du facturier
#vous n'aurez pas, normalement, besoin de modifier cette variable.
my $BASEBDD = "FACTURIER";
#serveur de base de donnees
-#remplacer "host" par le nom du serveur hébergeant MySQL.
-my $HOSTBDD = "host";
+#remplacer "%%DBSERV%%" par le nom du serveur hébergeant MySQL.
+my $HOSTBDD = "%%DBSERV%%";
#driver de base de donnees
@@ -110,7 +110,7 @@
#remplacer 'scriptalias' par le scriptalias du 'Facturier'
#si scriptalias = fact alors
#$CGIADR="/fact";
- $CGIADR="/ScriptAlias";
+ $CGIADR="/fact";
#$BASEAD contient le chemin absolu du répertoire facturier sur le serveur
@@ -118,14 +118,14 @@
#remplacer 'chemin repertoire principale (facturier/)' par le chemin du repertoire
#facturier : si le facturier est dans /var/www/html, alors :
#$BASEAD ="/var/www/html/facturier";
- $BASEAD ="chemin repertoire principal (facturier)";
+ $BASEAD ="%%WWWDIR%%/";
#$HTMLDOC contient le chemin de la commande htmldoc
#si la commande htmldoc que vous désirez utiliser est dans "/usr/bin/" faire
#$HTMLDOC="/usr/bin/htmldoc";
- $HTMLDOC="/usr/local/htmldoc-1.8.22/bin/htmldoc";
+ $HTMLDOC="%%LOCALBASE%%/bin/htmldoc";
###################################
#finvariables serveur à configurer
##################################
@@ -142,7 +142,7 @@
#$HTMLADRESSE indique au serveur web où se trouve les pages html utilisées par le facturier
# par apport au DocumentRoot. Si vous avez installé le facturier dans le DocumentRoot
#vous n'aurez pas besoin de modifier la valeur de $HTMLADRESSE
- $HTMLADRESSE='/html';
+ $HTMLADRESSE='/../facturier/html';
$HTMLADRUNGI = "$HTMLADRESSE/UNGI";
$HTMLADRUNGICONES = "$HTMLADRUNGI/icones";

View file

@ -1,40 +0,0 @@
@@ -70,24 +70,24 @@
#$USERBDD à pour valeur le login d'un utilisateur pouvant se connecter
#à la base de donnée 'FACTURIER' sur le serveur MySQL
- #remplacer 'user' par le login d'un utilisateur ayant le droit d'utiliser
+ #remplacer '%%DBOWN%%' par le login d'un utilisateur ayant le droit d'utiliser
#la base de donnée 'facturier' sur le serveur MySQL
@@ -70,24 +70,24 @@
#$MDPBDD contient la valeur du mot de passe de connection de l'utilisateur
#$USERBDD au serveur MySQL
- #remplacer 'password' par le mot de passe du login de l'utilisateur
+ #remplacer '%%DBPWD%%' par le mot de passe du login de l'utilisateur
#ci-dessus